import * as RD from '@devexperts/remote-data-ts';
import * as E from 'fp-ts/Eq';
import { Filter } from '../types';
/**
 * Gets a single row from a supabase table.
 *
 * @example
 * ```ts
 * const filter = useFilter<Foo>((query) => query.gt("id", "5"));
 * const result = useSingle<Foo>("foo", "*", filter);
 *
 * pipe(
 *   result,
 *   RD.fold3(
 *     () => <div>Loading...</div>,
 *     (e) => <div>Error {e}</div>,
 *     (row) => <div>{row.bar}</div>
 *   )
 * );
 * ```
 *
 * @param tableName - The table name to get a row from
 * @param selectArgs - Arguments for a select query
 * @param filter - A filter for your query
 * @param eq - An Eq for your data type
 * @returns A single row
 */
export declare const useSingle: <T = unknown>(tableName: string, selectArgs?: string, filter?: Filter<T> | undefined, eq?: E.Eq<T>) => RD.RemoteData<string, T>;
