import * as RD from '@devexperts/remote-data-ts';
import { Filter } from '../types';
import * as E from 'fp-ts/Eq';
/**
 * Updates some rows from a supabase table.
 * @example
 * ```tsx
 * const filter = useFilter<Foo>((query) => query.eq("id", "1"));
 * const [result, execute] = useUpdate<Foo>("foo");
 *
 * pipe(
 *   result,
 *   RD.fold(
 *     () => <button onClick={() => execute({ bar: "baz" }, filter)}></button>,
 *     () => <div>Loading...</div>,
 *     (e) => <div>Error {e}</div>,
 *     (rows) => (
 *       <div>
 *         Updated
 *         {rows.map((row) => (
 *           <div key={row.id}>
 *             {row.id} - {row.bar}
 *           </div>
 *         ))}
 *       </div>
 *     )
 *   )
 * );
 * ```
 * @param tableName - The table name to update inside of
 * @param eq - An Eq for your data type
 * @returns The rows that were updated, and a function to execute the update.
 */
export declare const useUpdate: <T = unknown>(tableName: string, eq?: E.Eq<T[]>) => [RD.RemoteData<string, T[]>, (values: Partial<T>, filter: Filter<T>) => Promise<void>];
